/***********************************************************************/
/*                                                                     */
/*      SUBROUTINE: spiback_observation_deadtime                       */
/*                                                                     */
/*      DESCRIPTION:                                                   */
/*      Returns the observation exposure good time intervals for each  */
/*      instrument pointing direction aand detector.                   */
/*                                                                     */
/***********************************************************************/
/*                                                                     */
/*      AUTHOR  : P.H.Connell - phc@star.sr.bham.ac.uk                 */
/*      ADDRESS : University of Birmingham - Space Research Group      */
/*                                                                     */
/*      HISTORY : Created 10.11.2002                                   */
/*                                                                     */
/***********************************************************************/

#include <isdc.h>		/* [DEF] ISDC int parameters */
#include <spiback_observe.h>	/* [DEF] Observation pointing/count data structure */

/*=====================================================================*/
/*    SUBROUTINE INPUT/OUTPUT ARGUMENT DEFINITION                      */
/*=====================================================================*/

 int spiback_observation_deadtime
(
 struct pointing_obs *obsv,	/* [IN]  Observation pointing/count header */
 char  *extn,			/* [OUT] Extension name */
 char  *phas,			/* [OUT] Phase at which an error occurred */
 int    stat			/* [I-O] Subroutine entry/exit status */
)

{				/* START OF SUBROUTINE */

/*=====================================================================*/
/*      W O R K I N G - S T O R A G E    D A T A                       */
/*=====================================================================*/
 DAL_ELEMENTP eadd;		/* Extension access address */
 char  comm[DAL_MAX_ATT_COMMENT_SIZE];		/* Keyword comment */
 char  unit[DAL_MAX_ATT_UNITS_SIZE];		/* Keyword value units */

/*=============================================================================*/
/*     Open "SPI.-OBS.-DTI" extension for LIVETIME for each pointing/detector. */
/*=============================================================================*/
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"searching the OGDI for exposure deadtime corrections");
 strcpy(extn,"SPI.-OBS.-DTI");
 stat = DALobjectFindElement(obsv->addr,extn,&eadd,stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"getting DEADC keyword");
 stat = DALattributeGetReal(eadd,"DEADC",&obsv->Deadtime,unit,comm,stat);
 if (stat != ISDC_OK) return stat;

 return stat;
}
