/***********************************************************************/
/*                                                                     */
/*      SUBROUTINE: spiback_observation_goodtime                       */
/*                                                                     */
/*      DESCRIPTION:                                                   */
/*      Returns the observation exposure good time intervals for each  */
/*      instrument pointing direction aand detector.                   */
/*                                                                     */
/***********************************************************************/
/*                                                                     */
/*      AUTHOR  : P.H.Connell - phc@star.sr.bham.ac.uk                 */
/*      ADDRESS : University of Birmingham - Space Research Group      */
/*                                                                     */
/*      HISTORY : Created 10.11.2002                                   */
/*                                                                     */
/***********************************************************************/

#include <isdc.h>		/* [DEF] ISDC int parameters */
#include <spiback_observe.h>	/* [DEF] Observation pointing/count data structure */

 int spiback_observation_goodtime
(
 struct pointing_obs *obsv,	/* [IN]  Observation pointing/count header */
 char  *extn,			/* [OUT] Extension name */
 char  *phas,			/* [OUT] Phase at which an error occurred */
 int    stat			/* [I-O] Subroutine entry/exit status */
)

{				/* START OF SUBROUTINE */

/*=====================================================================*/
/*      W O R K I N G - S T O R A G E    D A T A                       */
/*=====================================================================*/
 DAL_ELEMENTP eadd;		/* Extension access address */
 dal_dataType type = DAL_INT;
 char comm[DAL_MAX_ATT_COMMENT_SIZE];			/* Keyword comment */
 char unit[DAL_MAX_ATT_UNITS_SIZE];			/* Keyword value units */
 long nofv;

/*=============================================================================*/
/*     Open "SPI.-OBS.-GTI" extension and get GTIs for each pointing/detector. */
/*=============================================================================*/
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"searching the OGDI for pointing exposure goodtime intervals");
 strcpy(extn,"SPI.-OBS.-GTI");
 stat = DALobjectFindElement(obsv->addr,extn,&eadd,stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"getting DET_NUM keyword from GTI dataset");
 stat = DALattributeGetInt(eadd,"DET_NUM",&obsv->nofd,unit,comm,stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"getting DET_REF keyword");
 stat = DALattributeGetChar(eadd,"DET_REF",obsv->detref,unit,comm,stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"getting DATAMODE keyword");
 stat = DALattributeGetChar(eadd,"DATAMODE",obsv->datamode,unit,comm,stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"getting ONTIME keyword");
 stat = DALattributeGetReal(eadd,"ONTIME",&obsv->Ontime,unit,comm,stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"getting maximum number GTI start/stop pairs");
 stat = DALattributeGetInt(eadd,"MAXGTINM",&obsv->nofi,unit,comm,stat);
 if (stat != ISDC_OK) return stat;

/*=====================================================================*/
/*    Retrieve detector-no identity sequence from first pointing       */
/*=====================================================================*/
 strcpy(phas,"reading in detector-no identity sequence");

 stat =  DALtableGetColBins(eadd,"DET_ID",0,&type,1,obsv->nofd,&nofv,obsv->dseq,stat);
 if (stat != ISDC_OK) return stat;

 return stat;
}
