/***********************************************************************/
/*                                                                     */
/*      SUBROUTINE: spiback_observation_spectrum                       */
/*                                                                     */
/*      DESCRIPTION:                                                   */
/*      Retreives the boundaries of each count spectrum energy bin.    */
/*                                                                     */
/***********************************************************************/
/*                                                                     */
/*      AUTHOR  : P.H.Connell - phc@star.sr.bham.ac.uk                 */
/*      ADDRESS : University of Birmingham - Space Research Group      */
/*                                                                     */
/*      HISTORY : Created 10.11.2002                                   */
/*                                                                     */
/***********************************************************************/

#include <isdc.h>		/* [DEF] ISDC int parameters */
#include <spiback_observe.h>	/* [DEF] Observation pointing/count data structure */

 int spiback_observation_spectrum
(
 struct pointing_obs *obsv,	/* [IN]  Observation pointing/count header */
 char  *extn,			/* [OUT] Extension name */
 char  *phas,			/* [OUT] Phase at which an error occurred */
 int    stat			/* [I-O] Subroutine entry/exit status */
)

{				/* START OF SUBROUTINE */

/*=====================================================================*/
/*      W O R K I N G - S T O R A G E    D A T A                       */
/*=====================================================================*/
 int  n;
 long nofv;
 dal_float rval;
 DAL_ELEMENTP eadd;		/* Extension access address */
 dal_dataType type = DAL_FLOAT;

/*=====================================================================*/
/*    Open at "SPI.-EBDS-SET" extension and get no of energy bins.     */
/*=====================================================================*/
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"searching the OGDI for count spectrum energy binning");
 strcpy(extn,"SPI.-EBDS-SET");
 stat = DALobjectFindElement(obsv->addr,extn,&eadd,stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"getting no of spectrum energy bins");
 stat = DALtableGetNumRows(eadd,&obsv->nofe,stat);
 if (stat != ISDC_OK) return stat;

/*=====================================================================*/
/*      Get lower/upper energies of spectrum energy bins.              */
/*=====================================================================*/
 strcpy(&obsv->esca," ");

 for(n=1; n<=obsv->nofe; n++)
    {
    strcpy(phas,"getting lower energy bounds");
    stat = DALtableGetColBins(eadd,"E_MIN",0,&type,n,n,&nofv,&rval,stat);
    if (stat != ISDC_OK) return stat;
    obsv->elow[n-1] = rval;

    strcpy(phas,"getting upper energy bounds");
    stat = DALtableGetColBins(eadd,"E_MAX",0,&type,n,n,&nofv,&rval,stat);
    if (stat != ISDC_OK) return stat;
    obsv->eupp[n-1] = rval;
    }

 obsv->emin = obsv->elow[0];
 obsv->emax = obsv->eupp[obsv->nofe-1];

 for(n=1; n<=obsv->nofe; n++)
    {
    if (obsv->elow[n-1] < obsv->emin) obsv->emin = obsv->elow[n-1];
    if (obsv->eupp[n-1] > obsv->emax) obsv->emax = obsv->eupp[n-1];
    }

 return stat; 
}
