/**********************************************************************/
/*                                                                    */
/*     SUBROUTINE:  spiback_output_observ_keywords                    */
/*                                                                    */
/*     DESCRIPTION:                                                   */
/*     Updates FITS extension header data with observation keywords.  */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/*     AUTHOR  : P.H.Connell - phc@star.sr.bham.ac.uk                 */
/*     ADDRESS : University of Birmingham - Space Research Group      */
/*                                                                    */
/*     HISTORY : Created 14.11.2002                                   */
/*                                                                    */
/**********************************************************************/

#include <isdc.h>		/* [DEF] ISDC subroutine parameters */
#include <spiback_observe.h>	/* [DEF] Observation pointing/count data structure */

 int spiback_output_observ_keywords
(
 dal_element *eadd,		/* [IN]  Address of background component extension */
 struct pointing_obs *obsv,	/* [IN]  Observation count data parameters */
 char  *phas			/* [OUT] Last DAL I-O phase */
)

{				/* START OF SUBROUTINE CODE */

/*====================================================================*/
/*     W O R K I N G - S T O R A G E    D A T A                       */
/*====================================================================*/
 int    stat = 0;
 double Angl = 0.0;
 const  double Dzero = 0.0;

/*====================================================================*/
/*    Write observation description, pointings and detector keywords  */
/*====================================================================*/
 /* strcpy(phas,"writing OBJECT keyword");
 stat = DALattributePutChar(eadd,"OBJECT",obsv->desc,"","",stat);
 if (stat != ISDC_OK) return stat; */

 /* strcpy(phas,"writing OBSERVER keyword");
 stat = DALattributePutChar(eadd,"OBSERVER",obsv->observer,"","",stat);
 if (stat != ISDC_OK) return stat; */

 strcpy(phas,"writing DATAMODE keyword");
 stat = DALattributePutChar(eadd,"DATAMODE",obsv->datamode,"","",stat);
 if (stat != ISDC_OK) return stat;

 /* strcpy(phas,"writing OBS_ID keyword");
 stat = DALattributePutChar(eadd,"OBS_ID",obsv->file,"","",stat);
 if (stat != ISDC_OK) return stat; */

 strcpy(phas,"writing OGID keyword");
 stat = DALattributePutChar(eadd,"OGID",obsv->groupid,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing ISOC_NUM keyword");
 stat = DALattributePutInt(eadd,"ISOC_NUM",obsv->nofw,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing PT_NUM keyword");
 stat = DALattributePutInt(eadd,"PT_NUM",obsv->nofp,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DET_NUM keyword");
 stat = DALattributePutInt(eadd,"DET_NUM",obsv->nofd,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DET_REF keyword");
 stat = DALattributePutChar(eadd,"DET_REF",obsv->detref,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing EBIN_NUM keyword");
 stat = DALattributePutInt(eadd,"EBIN_NUM",obsv->nofe,"","",stat);
 if (stat != ISDC_OK) return stat;
	
/*=======================================================*/
/*     Write observation exposure time keywords          */
/*=======================================================*/
 strcpy(phas,"writing DATE-OBS keyword");
 stat = DALattributePutChar(eadd,"DATE-OBS",obsv->UTCstart,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DATE-END keyword");
 stat = DALattributePutChar(eadd,"DATE-END",obsv->UTCend,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing TSTART keyword");
 stat = DALattributePutReal(eadd,"TSTART",obsv->Start,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing TSTOP keyword");
 stat = DALattributePutReal(eadd,"TSTOP",obsv->End,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing TELAPSE keyword");
 stat = DALattributePutReal(eadd,"TELAPSE",obsv->Elapsed,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing ONTIME keyword");
 stat = DALattributePutReal(eadd,"ONTIME",obsv->Ontime,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing EXPOSURE keyword");
 stat = DALattributePutReal(eadd,"EXPOSURE",obsv->Ontime,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DEADC keyword");
 stat = DALattributePutReal(eadd,"DEADC",obsv->Deadtime,"","",stat);
 if (stat != ISDC_OK) return stat;

/*====================================================================*/
/*   Write observation pointing extent in RA/DEC in degrees.          */
/*====================================================================*/
 strcpy(phas,"writing RA_MIN keyword");
 Angl = obsv->RAmin;
 if (Angl < Dzero) Angl = 360.0 + Angl;
 stat = DALattributePutReal(eadd,"RA_MIN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DEC_MIN keyword");
 Angl = obsv->DECmin;
 stat = DALattributePutReal(eadd,"DEC_MIN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing RA_MEAN keyword");
 Angl = obsv->RAmid;
 if (Angl < Dzero) Angl = 360.0 + Angl;
 stat = DALattributePutReal(eadd,"RA_MEAN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DEC_MEAN keyword");
 Angl = obsv->DECmid;
 stat = DALattributePutReal(eadd,"DEC_MEAN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing RA_MAX keyword");
 Angl = obsv->RAmax;
 if (Angl < Dzero) Angl = 360.0 + Angl;
 stat = DALattributePutReal(eadd,"RA_MAX",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DEC_MAX keyword");
 Angl = obsv->DECmax;
 stat = DALattributePutReal(eadd,"DEC_MAX",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

/*====================================================================*/
/*   Write observation pointing extent in RA/DEC as text.             */
/*====================================================================*/
 strcpy(phas,"writing RA_MI_S keyword");
 stat = DALattributePutChar(eadd,"RA_MI_S",obsv->RAmint,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DEC_MI_S keyword");
 stat = DALattributePutChar(eadd,"DEC_MI_S",obsv->DECmint,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing RA_ME_S keyword");
 stat = DALattributePutChar(eadd,"RA_ME_S",obsv->RAmidt,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DEC_ME_S keyword");
 stat = DALattributePutChar(eadd,"DEC_ME_S",obsv->DECmidt,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing RA_MA_S keyword");
 stat = DALattributePutChar(eadd,"RA_MA_S",obsv->RAmaxt,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing DEC_MA_S keyword");
 stat = DALattributePutChar(eadd,"DEC_MA_S",obsv->DECmaxt,"","",stat);
 if (stat != ISDC_OK) return stat;

/*====================================================================*/
/*   Write observation pointing extent in galactic L2/B2 in degrees.  */
/*====================================================================*/
 strcpy(phas,"writing L2_MIN keyword");
 Angl = obsv->L2min;
 if (Angl < Dzero) Angl = 360.0 + Angl;
 stat = DALattributePutReal(eadd,"L2_MIN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing B2_MIN keyword");
 Angl = obsv->B2min;
 stat = DALattributePutReal(eadd,"B2_MIN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing L2_MEAN keyword");
 Angl = obsv->L2mid;
 if (Angl < Dzero) Angl = 360.0 + Angl;
 stat = DALattributePutReal(eadd,"L2_MEAN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing B2_MEAN keyword");
 Angl = obsv->B2mid;
 stat = DALattributePutReal(eadd,"B2_MEAN",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing L2_MAX keyword");
 Angl = obsv->L2max;
 if (Angl < Dzero) Angl = 360.0 + Angl;
 stat = DALattributePutReal(eadd,"L2_MAX",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 strcpy(phas,"writing B2_MAX keyword");
 Angl = obsv->B2max;
 stat = DALattributePutReal(eadd,"B2_MAX",Angl,"","",stat);
 if (stat != ISDC_OK) return stat;

 return stat;
}
